@@ -10,10 +10,9 @@ use Net::Whois::Norid;
 $Net::Whois::Raw::CHECK_FAIL = 1;
 $Net::Whois::Raw::OMIT_MSG = 1;
 
-use version; our $VERSION = qv('0.8.3');
+use version; our $VERSION = qv('0.8.4');
 
 use parent qw/Exporter/;
-our @EXPORT      = ();
 our @EXPORT_OK   = qw/all domain2orgnr orgnr_ok orgnr2domains/;
 our %EXPORT_TAGS = ( 'all' => [qw/domain2orgnr orgnr_ok orgnr2domains/] );
 
@@ -79,14 +78,15 @@ __END__
 No::OrgNr - Utility functions for Norwegian organizations' ID numbers
 
 =for html
-<a href="https://www.blogger.com/https://travis-ci.org/geirmyk/No-OrgNr"><img alt="Build Status" src="https://travis-ci.org/geirmyk/No-OrgNr.svg?branch=master" /></a>
-<a href="https://www.blogger.com/https://coveralls.io/github/geirmyk/No-OrgNr?branch=master"><img alt="Coverage Status" src="https://coveralls.io/repos/github/geirmyk/No-OrgNr/badge.svg?branch=master" /></a>
-<a href="https://www.blogger.com/https://badge.fury.io/pl/No-OrgNr"><img alt="CPAN version" src="https://badge.fury.io/pl/No-OrgNr.svg" /></a>
+<a href="https://travis-ci.org/geirmyk/No-OrgNr">
+<img alt="Build Status" src="https://travis-ci.org/geirmyk/No-OrgNr.svg?branch=master" /></a>
+<a href="https://badge.fury.io/pl/No-OrgNr">
+<img alt="CPAN version" src="https://badge.fury.io/pl/No-OrgNr.svg" /></a>
 
 
 =head1 VERSION
 
-This document describes No::OrgNr version 0.8.3
+This document describes No::OrgNr version 0.8.4
 
 
 =head1 SYNOPSIS
